@@ -123,6 +123,10 @@ class GlinkNode(Node):
 			self.glink = None
 
 	def render(self, context):
+		user_ip = getClientIpFromRequest(context['request'])
+		tracking_dict = getLocationFromIp(user_ip)
+		print tracking_dict
+
 		#height="42" width="42"
 		'''
 		glink_page = "'glink/" + str(self.glink.id) + "'"
@@ -136,6 +140,11 @@ class GlinkNode(Node):
 		return img_lead + img_url + on_click + glink_page + height + width + img_close
 		'''
 		if self.glink != None:
+			impressionTracking = ImpressionTracking(glink_id=self.glink, latitude=tracking_dict["Latitude"].strip(), 
+				longitude=tracking_dict["Longitude"].strip(), country=tracking_dict["Country"].strip(), 
+				city=tracking_dict["City"].strip())
+			impressionTracking.save()
+
 			a_lead = "<a href="
 			glink_page = "'/glink/" + str(self.glink.id) + "'>"
 			img_lead = "<img src="
@@ -148,7 +157,8 @@ class GlinkNode(Node):
 		else: 
 			return ""
 
-
+def tracker(request):
+	pass
 
 
 @register.assignment_tag
@@ -166,3 +176,7 @@ def glink(parser, token):
 	return node
 
 
+
+
+
+
